@@ -3,9 +3,9 @@
 ;; "sumibi.el" is a client for Sumibi server.
 ;;
 ;;   Copyright (C) 2002,2003,2004,2005 Kiyoka Nishyama
-;;   This program was derived fr yc.el-4.0.13(auther: knak)
+;;   This program was derived from yc.el-4.0.13(auther: knak)
 ;;
-;;     $Date: 2005/05/28 06:21:55 $
+;;     $Date: 2005/06/26 05:10:38 $
 ;;
 ;; This file is part of Sumibi
 ;;
@@ -27,7 +27,7 @@
 ;;;     $BG[I[>r7o(B: GPL
 ;;; $B:G?7HGG[I[85(B: http://sourceforge.jp/projects/sumibi/
 
-;;; $BK\%P!<%8%g%s(B 0.3.0 $B$O%F%9%HHG$G$9!#(B
+;;; $BK\%P!<%8%g%s$O%F%9%HHG$G$9!#(B
 ;;; $B%P!<%8%g%s7ONs(B 0.3.x $B$G$O$I$s$I$s5!G=DI2C$r9T$J$&$?$aF0:n$,0BDj$7$F$$$J$$2DG=@-$,$"$j$^$9!#(B
 ;;; $B0BDj;X8~$NJ}$O(B $B0BDjHG(B (0.2.x) $B$r$4;HMQ$/$@$5$$!#(B
 ;;; $BITL@$JE@$d2~A1$7$?$$E@$,$"$l$P(BSumibi$B$N%a!<%j%s%0%j%9%H$K;22C$7$F%U%#!<%I%P%C%/$r$*$M$,$$$7$^$9!#(B
@@ -40,7 +40,6 @@
 ;;;      1) sumibi.org$B$GF0:n$7$F$$$k(BSumibi Server$B$K@\B3$7$FMxMQ$7$^$9!#(B 
 ;;;      2) SSL$B>ZL@=q$r;HMQ$7!":GDc8B$N%;%-%e%j%F%#!<$O3NJ]$7$F$$$^$9!#(B 
 ;;;         SSL$B>ZL@=q$O(B CAcert( http://www.cacert.org/ )$B$N$b$N$r;H$C$F$$$^$9!#(B
-;;;      3) $B>-Mh(BSumibi Server$B$N%W%m%H%3%k$OJQ99$K$J$j$^$9!#(B
 ;;;
 ;;;   2. $B%P%0$,$^$@$^$@$"$j$^$9!#(B^_^;
 ;;;
@@ -240,48 +239,77 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
     (setq sumibi-init t)))
 
 
+;;
+;; $B%m!<%^;z$G=q$+$l$?J8>O$r(BSumibi$B%5!<%P!<$r;H$C$FJQ49$9$k(B
+;;
+(defun sumibi-soap-request (func-name arg-list)
+  (let (
+	(command
+	 (concat
+	  sumibi-curl " --silent --show-error "
+	  (format " --max-time %d " sumibi-server-timeout)
+	  (if sumibi-server-use-cert
+	    (if (not sumibi-server-cert-file)
+		(error "Error : cert file create miss!")
+	      (format "--cacert '%s' " sumibi-server-cert-file))
+	    " --insecure ")
+	  (format " --header 'Content-Type: text/xml' " sumibi-server-timeout)
+	  (format " --header 'SOAPAction:urn:SumibiConvert#%s' " func-name)
+	  sumibi-server-url " "
+	  (format (concat "--data '"
+			  "<?xml version=\"1.0\" encoding=\"utf-8\"?>"
+			  "  <SOAP-ENV:Envelope xmlns:SOAP-ENC=\"http://schemas.xmlsoap.org/soap/encoding/\""
+			  "   SOAP-ENV:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\""
+			  "   xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\""
+			  "   xmlns:xsi=\"http://www.w3.org/1999/XMLSchema-instance\""
+			  "   xmlns:xsd=\"http://www.w3.org/1999/XMLSchema\">"
+			  "  <SOAP-ENV:Body>"
+			  "    <namesp1:%s xmlns:namesp1=\"urn:SumibiConvert\">"
+			  (mapconcat
+			   (lambda (x)
+			     (format "    <in xsi:type=\"xsd:string\">%s</in>" x))
+			   arg-list
+			   " ")
+			  "    </namesp1:%s>"
+			  "  </SOAP-ENV:Body>"
+			  "</SOAP-ENV:Envelope>"
+			  "' ")
+		  func-name
+		  func-name
+		  func-name
+		  func-name
+		  ))))
+
+    (sumibi-debug-print (format "curl-command :%s\n" command))
+
+    (let* (
+	   (_xml
+	    (shell-command-to-string
+	     command))
+	   (_match
+	    (string-match "<s-gensym3[^>]+>\\(.+\\)</s-gensym3>" _xml)))
+	   
+      (sumibi-debug-print (format "curl-result-xml :%s\n" _xml))
+
+      (if _match 
+	  (decode-coding-string
+	   (base64-decode-string 
+	    (match-string 1 _xml))
+	   'euc-jp)
+	_xml))))
+
+      
 ;;
 ;; $B%m!<%^;z$G=q$+$l$?J8>O$r(BSumibi$B%5!<%P!<$r;H$C$FJQ49$9$k(B
 ;;
 (defun sumibi-henkan-request (yomi)
   (sumibi-debug-print (format "henkan-input :[%s]\n"  yomi))
-  
-
 
   (message "Requesting to sumibi server...")
   (let* (
-	 ;; $B%W%m%;%9MQ%3!<%G%#%s%0%7%9%F%`$N<+F0H=JL(B
-	 (p-encode (symbol-name (car (find-operation-coding-system 'start-process sumibi-curl "xxxx" sumibi-curl))))
-	 (encode 
-	  (cond 
-	   ((string-match "euc-jp" p-encode)
-	    "euc-jp")
-	   ((string-match "shift-jis" p-encode)
-	    "SJIS")
-	   ((string-match "sjis" p-encode)
-	    "SJIS")
-	   ((string-match "iso-2022-jp" p-encode)
-	    "ISO2022JP")
-	   ((string-match "utf-8" p-encode)
-	    "utf8")
-	   (t
-	    p-encode)))
-	 (command 
-	  (concat
-	   sumibi-curl " --silent --show-error "
-	   (format "--connect-timeout %d " sumibi-server-timeout)
-	   sumibi-server-url " "
-	   (format "--data 'string=%s&encode=%s' " yomi encode)
-	   (when sumibi-server-use-cert
-	     (if (not sumibi-server-cert-file)
-		 (error "Error : cert file create miss!")
-	       (format "--cacert '%s' " sumibi-server-cert-file)))))
-	 (result 
-	  (shell-command-to-string
-	   command)))
+	 (result (sumibi-soap-request "doSumibiConvertSexp" (list yomi))))
 
     (sumibi-debug-print (format "henkan-result:%S\n" result))
-    (sumibi-debug-print (format "curl-command :%s\n"  command))
     (if (eq (string-to-char result) ?\( )
 	(progn
 	 (message nil)
@@ -607,7 +635,7 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
 
     ;; $BO"A[%j%9%H$+$i(B _type $B$G0z$$$?(B index $BHV9f$r@_Dj$9$k$@$1$GNI$$!#(B
     (when _element
-      (setcar (nthcdr n sumibi-cand-n) (nth 2 _element))
+      (setcar (nthcdr n sumibi-cand-n) (nth 3 _element))
       (sumibi-select-update-display))))
 
 (defun sumibi-select-kanji ()
@@ -839,7 +867,7 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
 (set-language-info "Japanese" 'input-method "japanese-sumibi")
 (setq default-input-method "japanese-sumibi")
 
-(defconst sumibi-version "0.3.0")
+(defconst sumibi-version "0.3.2")
 (defun sumibi-version (&optional arg)
   "$BF~NO%b!<%IJQ99(B"
   (interactive "P")
